@@ -22,6 +22,7 @@ KasumiAddWindow::KasumiAddWindow(KasumiDic *aDictionary,
   dictionary = aDictionary;
 
   window = gtk_window_new(GTK_WINDOW_TOPLEVEL);
+  gtk_window_set_position (GTK_WINDOW(window), GTK_WIN_POS_MOUSE);
   gtk_window_set_title(GTK_WINDOW(window), _("Kasumi"));
   g_signal_connect(G_OBJECT(window), "delete_event",
                    G_CALLBACK(_call_back_add_window_delete_event), this);
@@ -281,11 +282,11 @@ KasumiAddWindow::KasumiAddWindow(KasumiDic *aDictionary,
   gtk_window_set_resizable(GTK_WINDOW(window),true);
 
   // set default window position
-  int x = conf->getPropertyValueByInt("DefaultWindowPosX");
-  int y = conf->getPropertyValueByInt("DefaultWindowPosY");
-  if(x >= 0 && y >= 0){
-    gtk_window_move(GTK_WINDOW(window),x,y);
-  }
+  //  int x = conf->getPropertyValueByInt("DefaultWindowPosX");
+  //  int y = conf->getPropertyValueByInt("DefaultWindowPosY");
+  //  if(x >= 0 && y >= 0){
+  //    gtk_window_move(GTK_WINDOW(window),x,y);
+  //  }
 
   if(conf->getPropertyValue("DefaultAddingSpelling") == "" && conf->getPropertyValueByBool("ImportSelectedText")){
     get_targets(SpellingEntry);
