@@ -24,7 +24,9 @@ KasumiMainWindow::KasumiMainWindow(KasumiDic *aDictionary,
   modificationFlag = false;
   
   window = gtk_window_new(GTK_WINDOW_TOPLEVEL);
+
   gtk_window_set_title(GTK_WINDOW(window), _("Kasumi"));
+  gtk_window_set_position (GTK_WINDOW(window), GTK_WIN_POS_MOUSE);
   g_signal_connect(G_OBJECT(window), "delete_event",
                    G_CALLBACK(_call_back_delete_event), this);
 
@@ -449,11 +451,11 @@ KasumiMainWindow::KasumiMainWindow(KasumiDic *aDictionary,
   gtk_widget_hide(VerbOptionPane);
 
   // set default window position
-  int x = conf->getPropertyValueByInt("DefaultWindowPosX");
-  int y = conf->getPropertyValueByInt("DefaultWindowPosY");
-  if(x >= 0 && y >= 0){
-    gtk_window_move(GTK_WINDOW(window),x,y);
-  }
+  //  int x = conf->getPropertyValueByInt("DefaultWindowPosX");
+  //  int y = conf->getPropertyValueByInt("DefaultWindowPosY");
+  //  if(x >= 0 && y >= 0){
+  //    gtk_window_move(GTK_WINDOW(window),x,y);
+  //  }
 
   refresh();
 
